@@ -2,7 +2,7 @@
     This file is part of Contact Editor.
 
     Copyright (C) 2016 eyeOS S.L.U., a Telefonica company, sales@eyeos.com
-    Copyright (C) 2016-2017 Laurent Montel <laurent.montel@kdab.com>
+    Copyright (C) 2016-2018 Laurent Montel <laurent.montel@kdab.com>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -49,7 +49,7 @@ void MessagingWidgetLister::loadContact(const KContacts::Addressee &contact)
         QString app, name, value;
         ContactEditor::Utils::splitCustomField(custom, app, name, value);
 
-        if (app.startsWith(QStringLiteral("messaging/"))) {
+        if (app.startsWith(QLatin1String("messaging/"))) {
             if (name == QLatin1String("All")) {
                 const QString protocol = app;
                 const QStringList names = value.split(QChar(0xE000), QString::SkipEmptyParts);
